@@ -37,7 +37,7 @@ use PPI::Statement ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.218';
+	$VERSION = '1.220';
 	@ISA     = 'PPI::Statement';
 }
 
@@ -74,11 +74,19 @@ false.
 =cut
 
 sub name {
-	my $self = shift;
+	my ($self) = @_;
 
-	# The second token should be the name, if we have one
-	my $Token = $self->schild(1) or return '';
-	$Token->isa('PPI::Token::Word') and $Token->content;
+	# Usually the second token is the name.
+	my $token = $self->schild(1);
+	return $token->content
+	  if defined $token and $token->isa('PPI::Token::Word');
+
+	# In the case of special subs whose 'sub' can be omitted (AUTOLOAD
+	# or DESTROY), the name will be the first token.
+	$token = $self->schild(0);
+	return $token->content
+	  if defined $token and $token->isa('PPI::Token::Word');
+	return '';
 }
 
 =pod
@@ -89,7 +97,9 @@ If it has one, the C<prototype> method returns the subroutine's prototype.
 It is returned in the same format as L<PPI::Token::Prototype/prototype>,
 cleaned and removed from its brackets.
 
-Returns false if the subroutine does not define a prototype
+Returns the subroutine's prototype, or undef if the subroutine does not
+define one. Note that when the sub has an empty prototype (C<()>) the
+return is an empty string.
 
 =cut
 
@@ -98,7 +108,7 @@ sub prototype {
 	my $Prototype = List::Util::first {
 		_INSTANCE($_, 'PPI::Token::Prototype')
 	} $self->children;
-	defined($Prototype) ? $Prototype->prototype : '';
+	defined($Prototype) ? $Prototype->prototype : undef;
 }
 
 =pod
