@@ -38,9 +38,9 @@ now, look at L<Perl::Critic::Utils>.
 use strict;
 use PPI::Token ();
 
-use vars qw{$VERSION @ISA %OPERATOR %QUOTELIKE};
+use vars qw{$VERSION @ISA %OPERATOR %QUOTELIKE %KEYWORDS};
 BEGIN {
-	$VERSION = '1.218';
+	$VERSION = '1.220';
 	@ISA     = 'PPI::Token';
 
 	# Copy in OPERATOR from PPI::Token::Operator
@@ -57,6 +57,35 @@ BEGIN {
 		'tr' => 'Regexp::Transliterate',
 		'y'  => 'Regexp::Transliterate',
 	);
+
+	# List of keywords is from regen/keywords.pl in the perl source.
+	%KEYWORDS = map { $_ => 1 } qw{
+		abs accept alarm and atan2 bind binmode bless break caller chdir chmod
+		chomp chop chown chr chroot close closedir cmp connect continue cos
+		crypt dbmclose dbmopen default defined delete die do dump each else
+		elsif endgrent endhostent endnetent endprotoent endpwent endservent
+		eof eq eval evalbytes exec exists exit exp fc fcntl fileno flock for
+		foreach fork format formline ge getc getgrent getgrgid getgrnam
+		gethostbyaddr gethostbyname gethostent getlogin getnetbyaddr
+		getnetbyname getnetent getpeername getpgrp getppid getpriority
+		getprotobyname getprotobynumber getprotoent getpwent getpwnam
+		getpwuid getservbyname getservbyport getservent getsockname
+		getsockopt given glob gmtime goto grep gt hex if index int ioctl join
+		keys kill last lc lcfirst le length link listen local localtime lock
+		log lstat lt m map mkdir msgctl msgget msgrcv msgsnd my ne next no
+		not oct open opendir or ord our pack package pipe pop pos print
+		printf prototype push q qq qr quotemeta qw qx rand read readdir
+		readline readlink readpipe recv redo ref rename require reset return
+		reverse rewinddir rindex rmdir s say scalar seek seekdir select semctl
+		semget semop send setgrent sethostent setnetent setpgrp
+		setpriority setprotoent setpwent setservent setsockopt shift shmctl
+		shmget shmread shmwrite shutdown sin sleep socket socketpair sort
+		splice split sprintf sqrt srand stat state study sub substr symlink
+		syscall sysopen sysread sysseek system syswrite tell telldir tie tied
+		time times tr truncate uc ucfirst umask undef unless unlink unpack
+		unshift untie until use utime values vec wait waitpid wantarray warn
+		when while write x xor y
+	};
 }
 
 =pod
@@ -133,12 +162,6 @@ sub method_call {
 }
 
 
-my %backoff = map { $_ => 1 } qw{
-    eq ne ge le gt lt
-    q qq qx qw qr m s tr y
-    pack unpack
-};
-
 sub __TOKENIZER__on_char {
 	my $class = shift;
 	my $t     = shift;
@@ -149,8 +172,8 @@ sub __TOKENIZER__on_char {
 		my $word = $1;
 		# Special Case: If we accidentally treat eq'foo' like
 		# the word "eq'foo", then just make 'eq' (or whatever
-		# else is in the %backoff hash.
-		if ( $word =~ /^(\w+)'/ && $backoff{$1} ) {
+		# else is in the %KEYWORDS hash.
+		if ( $word =~ /^(\w+)'/ && $KEYWORDS{$1} ) {
 		    $word = $1;
 		}
 		$t->{token}->{content} .= $word;
@@ -220,7 +243,7 @@ sub __TOKENIZER__commit {
 	# Special Case: If we accidentally treat eq'foo' like the word "eq'foo",
 	# then unwind it and just make it 'eq' (or the other stringy comparitors)
 	my $word = $1;
-	if ( $word =~ /^(\w+)'/ && $backoff{$1} ) {
+	if ( $word =~ /^(\w+)'/ && $KEYWORDS{$1} ) {
 	    $word = $1;
 	}
 
