@@ -23,7 +23,7 @@ use Params::Util  qw{_INSTANCE _CLASS _CODE _SCALAR0};
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.218';
+	$VERSION = '1.220';
 }
 
 
@@ -33,8 +33,8 @@ BEGIN {
 #####################################################################
 # Apply Handler Registration
 
-my %HANDLER = ();
-my @ORDER   = ();
+my %HANDLER;
+my @ORDER;
 
 # Yes, you can use this yourself.
 # I'm just leaving it undocumented for now.
