@@ -1,5 +1,8 @@
 package t::lib::PPI;
 
+use warnings;
+use strict;
+
 use File::Spec::Functions ':ALL';
 use Test::More;
 use Test::Object;
@@ -9,7 +12,7 @@ use PPI::Dumper;
 
 use vars qw{$VERSION};
 BEGIN {
-	$VERSION = '1.218';
+	$VERSION = '1.220';
 }
 
 
@@ -158,7 +161,7 @@ Test::Object->register(
 
 sub valid_compound_type {
 	my $document = shift;
-	my $compound = $document->find('PPI::Statement::Compound');
+	my $compound = $document->find('PPI::Statement::Compound') || [];
 	is(
 		scalar( grep { not defined $_->type } @$compound ),
 		0, 'All compound statements have defined ->type',
@@ -297,7 +300,7 @@ sub increment_testdir {
 		# Load the file
 		local *CODEFILE;
 		local $/ = undef;
-		open( CODEFILE, $codefile ) or die "open: $!";
+		open( CODEFILE, '<', $codefile ) or die "open: $!";
 		my $buffer = <CODEFILE>;
 		close( CODEFILE ) or die "close: $!";
 
